{# ~/.incept/templates/video_chapter.j2 #}
{
  "folder": "season_{{ numeric_prefix }}",
  "files": [
    { "file": "poster.jpg" },
    { "file": "fanart.jpg" },
    { "file": "background.jpg" },
    { "file": "logo.png" },
    { "file": "thumb.jpg" }
  ],
  "subfolders": [
    {
      "folder": ".",
      "subfolders": [
{% for lesson in lessons %}
        {{ lesson | tojson }}{% if not loop.last %},{% endif %}
{% endfor %}
      ]
    }
  ]
}
