{# ~/.incept/templates/video_lesson.j2 #}
{
  "folder": ".",
  "files": [
    {
      "file": "s{{ numeric_prefix }}e{{ episode_number }}_{{ lesson_slug|lower }}.{{ video_ext }}"
    },
    {
      "file": "s{{ numeric_prefix }}e{{ episode_number }}_{{ lesson_slug|lower }}.nfo",
      "template_content": {{ (
        "<episodedetails>\n"
        "  <title>" ~ lesson_title ~ "</title>\n"
        "  <season>" ~ numeric_prefix ~ "</season>\n"
        "  <episode>" ~ episode_number ~ "</episode>\n"
        "  <aired>" ~ aired|default("2025-01-01") ~ "</aired>\n"
        "  <plot>" ~ description ~ "</plot>\n"
        "  <thumb>s" ~ numeric_prefix ~ "e" ~ episode_number ~ "_" ~ lesson_slug|lower ~ "_fanart.jpg</thumb>\n"
        "  <fanart>s" ~ numeric_prefix ~ "e" ~ episode_number ~ "_" ~ lesson_slug|lower ~ "_fanart.jpg</fanart>\n"
        "  <banner>s" ~ numeric_prefix ~ "e" ~ episode_number ~ "_" ~ lesson_slug|lower ~ "_banner.jpg</banner>\n"
        "</episodedetails>\n"
      ) | tojson }}
    }
  ]
}
