{#
  This template defines a lesson as a file.
  - The file will be named: "<lesson_prefix>_<lesson_name>.<ext>"
  - The variable `ext` should be provided (for example, "hip", "py", or "txt").
#}
{
  "file": "{% if numeric_prefix %}{{ numeric_prefix }}_{% endif %}{{ lesson_name }}.{{ ext }}"
}
